inline_box_style_breaks_shaping

Function inline_box_style_breaks_shaping 

fn inline_box_style_breaks_shaping(style: &ComputedValues) -> (bool, bool)
Whether or not an inline box style breaks shaping at the start and end. The return value is (breaks_shaping_at_start, breaks_shaping_at_end).

From https://drafts.csswg.org/css-text/#boundary-shaping

Text shaping must be broken at inline box boundaries when any of the following are true for any box whose boundary separates the two typographic character units:

  • Any of margin/border/padding separating the two typographic character units in the inline axis is non-zero.
  • vertical-align is not baseline.
  • The boundary is a bidi isolation boundary.